Struct BlsKeyPair

pub struct BlsKeyPair<Pk: BlsPublicKeyType> { /* private fields */ }
Available on crate feature bls only.
A BLS12-381 key pair

Implementations

Source

impl<Pk: BlsPublicKeyType> BlsKeyPair<Pk>

pub fn from_seed(seed: &[u8]) -> Result<Self, Error>

Generate a new BLS key from a seed according to the KeyGen algorithm

pub fn bls_public_key(&self) -> &Pk::Buffer

Accessor for the associated public key

pub fn bls_secret_scalar(&self) -> Option<&Scalar>

Accessor for the associated secret key value, if any