JwkSerialize

Struct JwkSerialize 

pub struct JwkSerialize<'s, K: ToJwk> { /* private fields */ }
A wrapper type for serializing a JWK using serde

Implementations

Source

impl<'s, K: ToJwk> JwkSerialize<'s, K>

pub fn new(key: &'s K, mode: JwkEncoderMode) -> Self

Create a new instance

pub fn as_public(key: &'s K) -> Self

Create a new instance for encoding a public key

pub fn as_secret(key: &'s K) -> Self

Create a new instance for encoding a secret key

pub fn as_thumbprint(key: &'s K) -> Self

Create a new instance for encoding a JWK thumbprint

pub fn alg(self, alg: Option<KeyAlg>) -> Self

Set the key algorithm

pub fn key_ops(self, key_ops: Option<KeyOpsSet>) -> Self

Set the key operations

pub fn kid(self, kid: Option<&'s str>) -> Self

Set the key ID