pub struct BlsKeyPair<Pk: BlsPublicKeyType> { /* private fields */ }Available on crate feature
bls only.Expand description
A BLS12-381 key pair
Implementations
Sourceimpl<Pk: BlsPublicKeyType> BlsKeyPair<Pk>
impl<Pk: BlsPublicKeyType> BlsKeyPair<Pk>
Sourcepub fn from_seed(seed: &[u8]) -> Result<Self, Error>
pub fn from_seed(seed: &[u8]) -> Result<Self, Error>
Generate a new BLS key from a seed according to the KeyGen algorithm
Sourcepub fn bls_public_key(&self) -> &Pk::Buffer
pub fn bls_public_key(&self) -> &Pk::Buffer
Accessor for the associated public key
Sourcepub fn bls_secret_scalar(&self) -> Option<&Scalar>
pub fn bls_secret_scalar(&self) -> Option<&Scalar>
Accessor for the associated secret key value, if any